@@ -33,34 +33,34 @@ class QuotaTracker(object):
             )
 
         self._refresh_quota()
-        self.count = self._load_count()
+        self.current_quota = self._load_current_quota()
         self.max_quota = max_quota
         self.exceed_quota = False
 
     def is_exceeded_quota(self):
         self._validate_quota()
 
-        current_quota = self._load_count()
+        current_quota = self._load_current_quota()
         if current_quota >= self.max_quota:
             return True
         return False
 
-    def _load_count(self):
+    def _load_current_quota(self):
         log = read_json(f"{self.dir_path}/{self.filename}")
         return log["count"]
 
     def _save_count(self):
-        log = {"timestamp": int(time()), "count": self.count}
+        log = {"timestamp": int(time()), "count": self.current_quota}
         write_to_json(self.dir_path, self.filename, log)
 
     def get_current_quota(self):
-        return self.count
+        return self.current_quota
 
     def count_request(self, num=1):
-        self.count += num
+        self.current_quota += num
         self._save_count()
 
-    def show_quota(self):
+    def show_status(self):
         self.logger.info(f'CurrentQuota: {self.get_current_quota()}/{self.max_quota}')
 
     def _refresh_quota(self):
@@ -69,16 +69,15 @@ class QuotaTracker(object):
         now_time = localtime(time())
         if self.options.refresh_by == "month" and (now_time.tm_mon > log_time.tm_mon) or \
                 self.options.refresh_by == "day" and (now_time.tm_mday > log_time.tm_mday):
-            self.count = 0
+            self.current_quota = 0
             self._save_count()
 
     def _validate_quota(self):
         if self.get_current_quota() < self.options.warning_rate * float(self.max_quota):
             self.logger.info("QuotaStatus: OK")
-        elif self.get_current_quota() <= self.max_quota:
+        elif self.get_current_quota() < self.max_quota:
             self.logger.info(f"QuotaStatus: WARNING - Exceeded {self.options.warning_rate * 100}% of quota requests")
         else:
             self.logger.info(f"QuotaStatus: STOPPING - Exceeded 100% of quota requests")
             self.exceed_quota = True
         return self.exceed_quota
-
